/**
 * Plugin to extract keywords and key-phrases.
 *
 * @type {import('unified').Plugin<[Options?]>}
 */
export default function retextKeywords(
  options?: Options | undefined
): void | import('unified').Transformer
export type Parent = import('unist').Parent
export type Node = import('unist').Node
/**
 * Configuration.
 */
export type Options = {
  /**
   * Try to detect at most `maximum` `words` and `phrases`.
   *
   * Note that actual counts may differ.
   * For example, when two words have the same score, both will be returned.
   * Or when too few words exist, less will be returned. the same goes for
   * phrases.
   */
  maximum?: number | undefined
}
export type Keyphrase = {
  score: number
  weight: number
  stems: string[]
  value: string
  matches: PhraseMatch[]
}
export type Keyword = {
  matches: KeywordMatch[]
  score: number
  stem: string
}
export type PhraseMatch = {
  nodes: Node[]
  parent: Parent
}
export type KeywordMatch = {
  node: Node
  index: number
  parent: Parent
}
